(*************************************************************)
(* String helpers *)
(*************************************************************)
(* In LaTeX *)
let bold_string s  = "\\textbf{"^s^"}";;
let blue_string s  = "\\textcolor{blue!90!black}{"^s^"}";;
let red_string s   = "\\textcolor{red!80!black}{"^s^"}";;
let green_string s = "\\textcolor{green!80!blue}{"^s^"}";;
let vio_string s   = "\\textcolor{red!40!blue}{"^s^"}";;
let lambda ()      = "\\lambda";;
let rightarrow ()  = "\\rightarrow";;

(* In ANSI color mode *)
let bold_string  s = "\x1B[1m"^s^"\x1B[0m"
let blue_string  s = "\x1B[38;5;75m"^s^"\x1B[0m"
let red_string   s = "\x1B[38;5;204m"^s^"\x1B[0m"
let green_string s = "\x1B[38;5;118m"^s^"\x1B[0m"
let vio_string   s = "\x1B[38;5;219m"^s^"\x1B[0m"
let lambda ()      = "λ";;
let rightarrow ()  = "➙";;

let paren s = "("^s^")";;

(*************************************************************)
(* Fresh variable names generator - with imperative features
   inside. A function that, each time it is called, returns a
   new variable name. *)
(*************************************************************)
let fresh_var_name_gen =
  let x = ref 0 in
  let rec gen_rec () =
    incr x;
    (* "x_{"^(string_of_int !x)^"}" (\* LaTeX *\) *)
    "x_"^(string_of_int !x) (* Ansi *)
  in gen_rec;;
let gen = fresh_var_name_gen;; (* shorter name *)
